@@ -7,10 +7,10 @@ with 'MooseX::Getopt';
 use Redis 1.904;
 
 # ABSTRACT: Backup and restore your Redis data to and from JSON.
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 has _conn => (
-    is       => 'rw',
+    is       => 'ro',
     isa      => 'Redis',
     init_arg => undef,
     lazy     => 1,
@@ -121,19 +121,21 @@ Redis::Dump - Backup and restore your Redis data to and from JSON.
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
-    $ redis-dump --server 127.0.0.1:6379 --filter foo
-    {
-           "foo" : "1",
-    }
+    use Redis::Dump;
+    use Data::Dumper;
+
+    my $dump = Redis::Dump({ server => '127.0.0.6379', filter => 'foo' });
+
+    print Dumper( \$dump->run );
 
 =head1 DESCRIPTION
 
 It's a simple way to dump data from redis-server in JSON format or any format
-you want (you can use Redis::Dump class).
+you want.
 
 =head1 COMMAND LINE API
 
@@ -147,14 +149,7 @@ Provided by L<MooseX::Getopt>. Parses attributes init args from @ARGV.
 
 =head2 run
 
-Perfomas the actual dump, and you can use your code as:
-
-    use Redis::Dump;
-    use Data::Dumper;
-
-    my $dump = Redis::Dump({ server => '127.0.0.6379', filter => 'foo' });
-
-    print Dumper( \$dump->run );
+Perfomas the actual dump.
 
 =head1 ATTRIBUTES
 
